<div align="center">

# TorchLatent

![GitHub Workflow Status (with event)](https://img.shields.io/github/actions/workflow/status/speedcell4/torchlatent/unit-tests.yml?cacheSeconds=0)
![PyPI - Version](https://img.shields.io/pypi/v/torchlatent?label=pypi%20version&cacheSeconds=0)
![PyPI - Downloads](https://img.shields.io/pypi/dm/torchlatent?cacheSeconds=0)

</div>

## Installation

`python -m pip torchlatent`

## Latent Structures

- [x] Conditional Random Fields (CRF)
- [x] Cocke–Kasami-Younger Algorithm (CKY)
- [ ] Probabilistic Context-free Grammars (CFG)
- [ ] Connectionist Temporal Classification (CTC)
- [ ] Recurrent Neural Network Grammars (RNNG)
- [ ] Non-Projective Dependency Tree (Matrix-tree Theorem)
- [ ] Dependency Model with Valence (DMV)
- [ ] Autoregressive Decoding (Beam Search)
